==> haskell-hpack-0.31.1-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.31.1
id: hpack-0.31.1-EASdW1hCkor3pA4wbMfH0h
key: hpack-0.31.1-EASdW1hCkor3pA4wbMfH0h
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: A modern format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: 0f29d61dba56851bb0b0e411fdcc567f
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.License Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
                Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
                Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
                Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.6.4/site-local/hpack-0.31.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hpack-0.31.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hpack-0.31.1
hs-libraries: HShpack-0.31.1-EASdW1hCkor3pA4wbMfH0h
depends:
    Cabal-2.4.0.1 Glob-0.10.0-14GRnAxrpa520qabOGkfDr
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0
    bifunctors-5.5.3-Gqod99cZkyGGOnuHypdgm4 bytestring-0.10.8.2
    containers-0.6.0.1 cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1
    http-client-0.6.2-6WY3aYUXuTuLnMgMF4fTs8
    http-client-tls-0.3.5.3-6coN3fiZwOp2fF3bnjCHvZ
    http-types-0.12.3-7ETbM18iSLZB08qGmmgPmt
    infer-license-0.2.0-BVGshMJUwlPGbTlA6oqN5C pretty-1.1.3.6
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    yaml-0.11.0.0-EufHeUEvddD7XUSxtVqg4M
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.31.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.31.2
id: hpack-0.31.2-rfbSodNuM96XEMYIOVwc7
key: hpack-0.31.2-rfbSodNuM96XEMYIOVwc7
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: A modern format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: 9db003cac25b81953ad693f99b2890a0
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.License Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
                Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
                Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
                Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.6.4/site-local/hpack-0.31.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hpack-0.31.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hpack-0.31.2
hs-libraries: HShpack-0.31.2-rfbSodNuM96XEMYIOVwc7
depends:
    Cabal-2.4.0.1 Glob-0.10.0-14GRnAxrpa520qabOGkfDr
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl base-4.12.0.0
    bifunctors-5.5.3-Gqod99cZkyGGOnuHypdgm4 bytestring-0.10.8.2
    containers-0.6.0.1 cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1
    http-client-0.6.2-6WY3aYUXuTuLnMgMF4fTs8
    http-client-tls-0.3.5.3-6coN3fiZwOp2fF3bnjCHvZ
    http-types-0.12.3-7ETbM18iSLZB08qGmmgPmt
    infer-license-0.2.0-BVGshMJUwlPGbTlA6oqN5C pretty-1.1.3.6
    scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
    yaml-0.11.0.0-EufHeUEvddD7XUSxtVqg4M
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
